package com.ynet.life.sujrb.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.action.LifeJDBCAction;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.math.BigDecimal;
import java.sql.Connection;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_ynet_life_sujrb_action.jar:com/ynet/life/sujrb/action/FeeCalculateAction.class */
public class FeeCalculateAction extends LifeJDBCAction {
    private String inputFeeSysFlag;
    private String inputFeeAccountNo;
    private String inputFeeBusinessCode;
    private String inputFeeTranAmount;
    private String inputFeeVipFlag;
    private String inputFeeBusinessDiscount;
    private String outputFeeAmount;
    private String outputFeeDiscount;
    private String outputFeeType;
    private boolean throwException = true;
    private static final String IN_FEE_SYS_FLAG = "fc_inputFeeSysFlag";
    private static final String IN_FEE_ACC_NO = "fc_inputFeeAccountNo";
    private static final String IN_FEE_BSN_CODE = "fc_inputFeeBusinessCode";
    private static final String IN_FEE_TRA_AMT = "fc_inputFeeTranAmount";
    private static final String IN_FEE_VIPFLAG = "fc_inputFeeVipFlag";
    private static final String IN_FEE_BUSINESSDISCOUNT = "fc_inputFeeBusinessDiscount";
    private static final String OUT_FEE_AMOUNT = "fc_outputFeeAmount";
    private static final String OUT_FEE_DISCOUNT = "fc_outputFeeDiscount";
    private static final String OUT_FEE_TYPE = "fc_outputFeeType";
    private static final String PROC_RET_CODE = "fc_outputProcRetCode";

    public String getOutputFeeType() {
        return this.outputFeeType;
    }

    public void setOutputFeeType(String outputFeeType) {
        this.outputFeeType = outputFeeType;
    }

    public String execute(Context context) throws GENEException {
        int result;
        Connection connection = null;
        try {
            String systemFlag = this.inputFeeSysFlag;
            if (context.containsKey(this.inputFeeSysFlag)) {
                systemFlag = (String) context.get(this.inputFeeSysFlag);
            }
            addDataField(context, IN_FEE_SYS_FLAG, systemFlag);
            addDataField(context, IN_FEE_ACC_NO, context.getDataValue(this.inputFeeAccountNo));
            addDataField(context, IN_FEE_BSN_CODE, context.getDataValue(this.inputFeeBusinessCode));
            addDataField(context, IN_FEE_TRA_AMT, context.getDataValue(this.inputFeeTranAmount));
            addDataField(context, IN_FEE_VIPFLAG, context.getDataValue(this.inputFeeVipFlag));
            if (StringUtils.isNotEmpty((String) context.get(this.inputFeeBusinessDiscount))) {
                String businessDiscount = (String) context.getDataValue(this.inputFeeBusinessDiscount);
                addDataField(context, IN_FEE_BUSINESSDISCOUNT, businessDiscount);
            } else {
                addDataField(context, IN_FEE_BUSINESSDISCOUNT, "1.00");
            }
            addDataField(context, OUT_FEE_AMOUNT, "");
            addDataField(context, OUT_FEE_DISCOUNT, "");
            addDataField(context, PROC_RET_CODE, "");
            addDataField(context, OUT_FEE_TYPE, "");
            connection = LifeDBAccess.getConnection(getDataSource());
            String retCode = LifeDBAccess.executeProcedure(context, connection, "feeCalculate");
            try {
                result = Integer.parseInt(retCode);
            } catch (NumberFormatException unused) {
                result = -1;
            }
            if (result != 0) {
                throw new TranFailException("EBPB0101", "计算当前交易手续费异常！");
            }
            if (this.outputFeeAmount != null && this.outputFeeAmount.length() > 0) {
                String feeAmount = (String) context.getDataValue(OUT_FEE_AMOUNT);
                BigDecimal amount = new BigDecimal(feeAmount).setScale(2, 0);
                context.put(this.outputFeeAmount, amount.toString());
            }
            if (this.outputFeeType != null && this.outputFeeType.length() > 0) {
                String feeType = (String) context.getDataValue(OUT_FEE_TYPE);
                context.put(this.outputFeeType, feeType);
            }
            if (this.outputFeeDiscount != null && this.outputFeeDiscount.length() > 0) {
                String feeDiscount = (String) context.getDataValue(OUT_FEE_DISCOUNT);
                BigDecimal discount = new BigDecimal(feeDiscount).setScale(2, 0);
                context.put(this.outputFeeDiscount, discount.toString());
            }
            return "0";
        } catch (GENEException empe) {
            Trace.logError("LifeAction", empe.getMessage(), empe);
            if (this.throwException) {
                throw new TranFailException("EBPB0101", "计算当前交易手续费异常！");
            }
            return "0";
        } finally {
            LifeDBAccess.releaseConnection(getDataSource(), connection);
        }
    }

    public String getInputFeeBusinessDiscount() {
        return this.inputFeeBusinessDiscount;
    }

    public void setInputFeeBusinessDiscount(String inputFeeBusinessDiscount) {
        this.inputFeeBusinessDiscount = inputFeeBusinessDiscount;
    }

    private void addDataField(Context context, String name, Object value) throws GENEException {
        if (context.containsKey(name)) {
            context.put(name, value);
        } else {
            context.addDataField(name, value);
        }
    }

    public void setInputFeeSysFlag(String inputFeeSysFlag) {
        this.inputFeeSysFlag = inputFeeSysFlag;
    }

    public void setInputFeeAccountNo(String inputFeeAccountNo) {
        this.inputFeeAccountNo = inputFeeAccountNo;
    }

    public void setInputFeeBusinessCode(String inputFeeBusinessCode) {
        this.inputFeeBusinessCode = inputFeeBusinessCode;
    }

    public void setInputFeeTranAmount(String inputFeeTranAmount) {
        this.inputFeeTranAmount = inputFeeTranAmount;
    }

    public void setInputFeeVipFlag(String inputFeeVipFlag) {
        this.inputFeeVipFlag = inputFeeVipFlag;
    }

    public void setOutputFeeAmount(String outputFeeAmount) {
        this.outputFeeAmount = outputFeeAmount;
    }

    public void setOutputFeeDiscount(String outputFeeDiscount) {
        this.outputFeeDiscount = outputFeeDiscount;
    }

    public void setThrowException(String throwException) {
        this.throwException = Boolean.valueOf(throwException).booleanValue();
    }
}
